==> rutorrent-3.9.tar.gz: ruTorrent-3.9/lang/sv.js <==
﻿/*
 * Swedish language file.
 *
 * Author: Magnus Holm (holmen@brasse.se)
 */

var theUILang =
{
 General			: "Allmänt",
 Downloads			: "Nedladdningar",
 Connection			: "Anslutning",
 BitTorrent			: "BitTorrent",
 Advanced			: "Avancerat",
 User_Interface 		: "Användargränssnitt",
 Confirm_del_torr		: "Bekräfta borttagning av torrents",
 Update_GUI_every		: "Uppdatera användargränssnitt varje",
 ms				: "ms",
 Alt_list_bckgnd		: "Alternera bakgrundsfärg i lista",
 Show_cat_start 		: "Visa kategorier vid uppstart",
 Show_det_start 		: "Visa detaljer vid upstart",
 Dnt_start_down_auto		: "Starta inte nedladdningen automatiskt",
 Listening_Port 		: "Lyssnade port",
 Port_f_incom_conns		: "Port för inkommande anslutning",
 Rnd_port_torr_start		: "Slumpa port varje gång rTorrent startar",
 Type				: "Typ",
 Bandwidth_Limiting		: "Bandbreddsbegränsning",
 Global_max_upl 		: "Global högsta uppladdningshastighet",
 unlimited			: "Obegränsad",
 Glob_max_downl 		: "Global lägsta nedladdningshastighet",
 Add_bittor_featrs		: "Ytterligare egenskaper för BitTorrent",
 En_DHT_ntw			: "Aktivera DHT-nätverk",
 Peer_exch			: "Peer-utbyte",
 Ip_report_track		: "IP/Värdnamn att rapportera till tracker",
 Disabled			: "Inaktiverad",
 Enabled			: "Aktiverad",
 ruTorrent_settings		: "Inställningar",
 Doesnt_support 		: "ruTorrent har inte stöd för din webbläsare",
 Name				: "Namn",
 Status 			: "Status",
 Size				: "Storlek",
 Done				: "Färdigt",
 Downloaded			: "Nedladdat",
 Uploaded			: "Uppladdat",
 Ratio				: "Ratio",
 DL				: "NL",
 UL				: "UL",
 ETA				: "ETA",
 Label				: "Etikett",
 Peers				: "Peers",
 Seeds				: "Seedare",
 Remaining			: "Återstående",
 Priority			: "Prioritet",
 Not_torrent_file		: "Filen måste vara en .torrent-fil",
 Pausing			: "Pausad",
 Seeding			: "Seedar",
 Downloading			: "Laddar ner",
 Checking			: "Kontrollerar",
 Error				: "Fel",
 Queued 			: "Köad",
 Finished			: "Färdiga",
 Stopped			: "Stoppad",
 Request_timed_out		: "Tidsgränsen för anslutning till rTorrent har överskridits.",
 Start				: "Start",
 Pause				: "Paus",
 Stop				: "Stopp",
 Force_recheck			: "Tvinga omkontroll",
 New_label			: "Ny etikett...",
 Remove_label			: "Ta bort etikett",
 Labels 			: "Etiketter",
 Remove 			: "Ta bort",
 Delete_data			: "Radera filer",
 Remove_and			: "Ta bort och...",
 Details			: "Detaljer...",
 Properties			: "Egenskaper...",
 of				: "av", //this two creates line
 connected			: "ansluten", //  XX of YY connected
 High_priority			: "Hög",
 Normal_priority		: "Normal",
 Low_priority			: "Låg",
 Dont_download			: "Ladda inte ner",
 Files				: "Filer",
 Logger 			: "Logg",
 s				: "s", // part of "KB/s"
 bytes				: "bytes",
 KB				: "KiB",
 MB				: "MiB",
 GB				: "GiB",
 TB				: "TiB",
 PB				: "PiB",
 Loading			: "Laddar...",
 Torrent_file			: "Torrent-fil",
 Torrent_URL			: "Torrent-address",
 Torrent_properties		: "Torrentegenskaper",
 Trackers			: "Trackers",
 Bandwidth_sett 		: "Bandbreddsinställningar",
 Number_ul_slots		: "Antal uppladdningar",
 Peer_ex			: "Peer-utbyte",
 Enter_label_prom		: "Ange ny etikett för markerad(e) torrent(er).",
 Remove_torrents		: "Ta bort torrent(er)",
 Rem_torrents_prompt		: "Vill du verkligen ta bort markerad(e) torrent(er)?",
 All				: "Alla",
 Active 			: "Aktiva",
 Inactive			: "Inaktiva",
 No_label			: "Utan etikett",
 Transfer			: "Överföring",
 Time_el			: "Förfluten tid",
 Share_ratio			: "Delningsratio",
 Down_speed			: "Nedladdningshastighet",
 Ul_speed			: "Uppladdningshastighet",
 Wasted 			: "Skrotat",
 Tracker			: "Tracker",
 Track_URL			: "Tracker-address",
 Track_status			: "Tracker-status",
 Created_on			: "Skapad",
 Save_as			: "Spara som",
 Comment			: "Kommentar",
 add_button			: "Lägg till fil",
 add_url			: "Lägg till URL",
 ok				: "OK",
 Cancel 			: "Avbryt",
 mnu_add			: "Lägg till torrent",
 mnu_remove			: "Ta bort",
 mnu_start			: "Start",
 mnu_pause			: "Paus",
 mnu_stop			: "Stopp",
 mnu_rss			: "RSS-nedladdare",
 mnu_settings			: "Inställningar",
 mnu_search			: "Sök",
 mnu_lang			: "Språk",
 torrent_add			: "Lägg till torrent", /*Caption of torrent add box*/
 time_w 			: "v ", /*for x weeks*/
 time_d 			: "d ", /*for x days remaining*/
 time_h 			: "t ", /*for x hours remaining*/
 time_m 			: "m ", /*for x minutes remaining*/
 time_s 			: "s ", /*for x seconds remaining*/
 Base_directory 		: "Katalog",
 Number_Peers_min		: "Minsta antal peers",
 Number_Peers_max		: "Högsta antal peers",
 Tracker_Numwant		: "Önskat antal peers",
 Number_Peers_For_Seeds_min	: "Minsta antal peers för seed.",
 Number_Peers_For_Seeds_max	: "Högsta antal peers för seed.",
 Enable_port_open		: "Öppna lyssnande port",
 dht_port			: "UDP-port för användning av DHT",
 Other_Limiting 		: "Övriga begränsningar",
 Number_dl_slots		: "Antal nedladdningar",
 Glob_max_memory		: "Högsta tillåtna minnesanvändning",
 Glob_max_files 		: "Högsta tillåtna antal öppnade filer",
 Glob_max_http			: "Högsta tillåtna antal http-anslutningar",
 Other_sett			: "Övrigt",
 Directory_For_Dl		: "Standardmapp för nedladdningar",
 Check_hash			: "Kontrollera hash efter nedladdning",
 Hash				: "Hash",
 DisableTracker 		: "Inaktivera",
 EnableTracker			: "Aktivera",
 ClientVersion			: "Klient",
 Flags				: "Flaggor",
 ReqTimeout			: "Tidsbegränsningen har överskidits",
 GetTrackerMessage		: "Motta meddelanden från tracker",
 Help				: "Hjälp",
 Speed				: "Hastighet",
 Dont_add_tname 		: "Lägg inte till torrent-namn till sökväg",
 Free_Disk_Space		: "Ledigt utrymme",
 badXMLRPCVersion		: "rTorrent är kompilerad med fel version av xmlrpc-C-biblioteket, utan i8-stöd. Version måste vara > = 1.11. Vissa funktioner kommer att vara otillgängliga.",
 badLinkTorTorrent		: "Ingen anslutning till rTorrent. Kontrollera om det verkligen körs. Kontrollera $scgi_port- och $scgi_host-inställningarna i config.php och scgi_port i rTorrent's konfigurationsfil.",
 badUploadsPath 		: "Webbserveranvändaren har inte läs-/skriv-/exekveringsåtkomst till torrent-katalogen. Du kan ej lägga till torrenter via ruTorrent.",
 badSettingsPath		: "Webbserveranvändaren har inte läs-/skriv-/exekveringsåtkomst till inställningskatalogen. Inställningarna i ruTorrent kan inte sparas.",
 mnu_help			: "Hjälp",
 badUploadsPath2		: "rTorrent-användaren måste ha läs-/exekveringsåtkomst till torrent-katalogen. Du kan ej lägga till torrenter via ruTorrent.",
 View				: "Visa",
 AsList 			: "Som lista",
 AsTree 			: "Som träd",
 Group				: "Grupp",
 SuperSeed			: "Super-seed",
 badTestPath			: "rTorrent-användaren måste ha läs-/exekveringsåtkomst till filen ./test.sh",
 badSettingsPath2		: "rTorrent-användaren måste ha läs-/exekveringsåtkomst till inställningskatalogen.",
 scrapeDownloaded		: "Nedladdat",
 Total				: "Totalt",
 PCRENotFound			: "PHP PCRE-modulen är inte installerad. ruTorrent kommer inte att fungera.",
 addTorrentSuccess		: "Torrent lades till.",
 addTorrentFailed		: "Misslyckades att lägga till torrent.",
 pnlState			: "Tillstånd",
 newLabel			: "Ny etikett",
 enterLabel			: "Ange etikett",
 UIEffects			: "Visa effekter för gränssnittselement.",
 Plugins			: "Insticksprogram",
 plgName			: "Namn",
 plgStatus			: "Status",
 plgLoaded			: "Laddad",
 plgDisabled			: "Inte laddad",
 plgVersion			: "Version",
 plgAuthor			: "Upphovsman",
 plgDescr			: "Beskrivning",
 mnu_go 			: "Kör",
 pluginCantStart		: "Insticksprogram startade inte.",
 doFastResume			: "Snabb återupptagning",
 innerSearch			: "Lokala torrenter",
 removeTeg			: "Ta bort tagg",
 errMustBeInSomeHost		: "ruTorrent och rTorrent måste vara installerade på samma värd. Insticksprogram kommer inte att fungera.",
 warnMustBeInSomeHost		: "ruTorrent och rTorrent måste vara installerade på samma värd. Vissa funktioner kommer att vara otillgängliga.",
 plgShutdown			: "Stoppa",
 limit				: "Gräns",
 speedList			: "Hastighetslista (kommaseparerad)",
 ClearButton			: "Rensa",
 dontShowTimeouts		: "Ignorera meddelanden om tidsgränsöverskridning",
 fullTableRender		: "Full renderinga av stora tabeller",
 showScrollTables		: "Visa tabellinnehåll under skrollning",
 idNotFound			: "rTorrent-användaren kan inte komma åt 'id'. Vissa funktioner kommer att vara otillgängliga.",
 gzipNotFound			: "Webbserveranvändaren kan inte komma åt 'gzip'. ruTorrent kommer inte att fungera.",
 cantObtainUser 		: "ruTorrent kan inte fastställa användar-id för rTorrent-användare. Vissa funktioner kommer att vara otillgängliga.",
 retryOnErrorTitle		: "Om rTorrent är inte tillgängligt försök igen efter",
 retryOnErrorList		: { 0: "Försök inte igen", 30: "30 sek", 60: "1 min", 120: "2 min", 300: "5 min", 900: "15 min" },
 statNotFound			: "rTorrent-användaren kan inte komma åt 'stat'. Vissa funktioner kommer att vara otillgängliga.",
 statNotFoundW			: "Webbserveranvändaren kan inte komm åt 'stat'. Vissa funktioner kommer att vara otillgängliga.",
 badrTorrentVersion		: "Insticksprogram kräver rTorrent-version >=",
 badPHPVersion			: "Insticksprogram kräver PHP-version >=",
 rTorrentExternalNotFoundError	: "Insticksprogrammet kommer inte att fungera. rTorrent-användaren kan inte komma åt externt program",
 rTorrentExternalNotFoundWarning: "Vissa funktioner kommer att vara otillgängliga. rTorrent-användaren kan inte komma åt externt program",
 webExternalNotFoundError	: "Insticksprogrammet kommer inte att fungera. Webbserveranvändaren kan inte komma åt externt program",
 webExternalNotFoundWarning	: "Vissa funktioner kommer att vara otillgängliga. Webbserveranvändaren kan inte komma åt externt program",
 rTorrentBadScriptPath		: "Insticksprogrammet kommer inte att fungera. rTorrent-användaren måste ha läs-/exekveringsåtkomst till filen",
 rTorrentBadPHPScriptPath	: "Insticksprogrammet kommer inte att fungera. rTorrent-användaren måste ha läsrättigheter till filen",
 dependenceError		: "Insticksprogrammet kommer inte att fungera. Det kräver insticksprogram",
 peerAdd			: "Lägg till Peer...",
 peerBan			: "Banna",
 peerKick			: "Sparka ut",
 peerSnub			: "Nonchalera",
 peerDetails			: "Detaljer",
 peerUnsnub			: "Ta bort nonchalering",
 peerAddLabel			: "Ange IP/Värdnamn[:port]",
 noTorrentList			: "Torrentlista ännu inte tillgänglig, anslutning till rTorrent ej etablerad.",
 yes				: "ja",
 no				: "nej",
 DateFormat			: "Datumformat",
 DLStrategy			: "Nedladdningsstrategi",
 prioritizeFirst		: "Inledande bit först",
 prioritizeLast 		: "Avslutande bit först",
 prioritizeNormal		: "Normal",
 updateTracker			: "Updatera trackers",
 scrapeUpdate			: "Senaste uppdatering",
 trkInterval			: "Intervall",
 logAutoSwitch			: "Byt automatiskt till 'Logg'flik",
 showLabelSize			: "Show label size",
 phpParameterUnavailable	: "PHP-direktivet register_argc_argv är inställt på OFF. Byt till ON, annars kommer några insticksprogram inte fungera korrekt.",
 addTorrentFailedURL		: "Det gick inte att lägga till torrent. Kan inte hämta webbadress.",
 addTorrentFailedFile		: "Det gick inte att lägga till torrent. Hämtat innehåll är inte en giltig torrentfil.",
 addTorrentFailedDirectory	: "Det gick inte att lägga till torrent. Felaktig nedladdningskatalog har angetts.",
 plgLaunch			: "Starta",
 plgLocked			: "Obligatorisk",
 phpExtensionNotFoundWarning	: "Vissa funktioner kommer att vara otillgängliga. PHP-tillägg måste installeras",
 phpExtensionNotFoundError	: "Insticksprogrammet kommer inte att fungera. PHP-tillägg måste installeras",
 trkPrivate			: "Privat",
 dontSet			: "Ställ inte in",
 webBadSessionError		: "Insticksprogrammet kommer inte att fungera. Webbserveranvändaren måste ha exekveringsåtkomst till rTorrent's session-katalog",
 webBadSessionWarning		: "Vissa funktioner kommer att vara otillgängliga. Webbserveranvändaren måste ha exekveringsåtkomst till rTorrent's session-katalog",
 Developers			: "Utvecklare",
 Check_new_version		: "Kolla efter ny version",
 here				: "här",
 Num_No 			: "nr.", // This means "Number". To be used as header for number count, e.g.: throttle/ratio plugin
 This_screen			: "Detta fönster",
 About_program			: "Om ruTorrent",
 Toggle_menu			: "Visa/dölj meny",
 Toggle_details 		: "Visa/dölj detaljer",
 Toggle_categories		: "Visa/dölj kategorier",
 Delete_current_torrents	: "Ta bort aktuell(a) torrent(er)",
 Select_all			: "Markera alla",
 Deselect_all			: "Avmarkera alla",
 showSpeedInTitle		: "Visa hastighet i titel",
 badTempPath 			: "Webserver user doesn't have read/write/execute access to the tmp directory. ruTorrent will not work.",
 badTempPath2			: "rTorrent user must have read/execute access to the tmp directory. ruTorrent will not work.",
 doRandomizeHash		: "Randomize info hashes for cross-seeding",
 Recreate_files 		: "Queue files recreation",
 Address			: "Address",
 PeerDL 			: "Peer DL",
 PeerDownloaded 		: "Peer Downloaded",
 Save_path			: "Save path",
 registerMagnet			: "Try to register magnet protocol handler at start",
 linkTorTorrentRestored		: "Connection to rTorrent established.",
 removeAllTegs			: "Remove all tags"
};

==> rutorrent-4.0.4.tar.gz: ruTorrent-4.0.4/lang/sv.js <==
﻿/*
 * Swedish language file.
 *
 * Author: Magnus Holm (holmen@brasse.se)
 */

var theUILang =
{
 General			: "Allmänt",
 Downloads			: "Nedladdningar",
 Connection			: "Anslutning",
 BitTorrent			: "BitTorrent",
 Format			: "Format",
 Advanced			: "Avancerat",
 User_Interface			: "Användargränssnitt",
 Confirm_del_torr		: "Bekräfta borttagning av torrents",
 Update_GUI_every		: "Uppdatera användargränssnitt varje",
 ms				: "ms",
 Alt_list_bckgnd		: "Alternera bakgrundsfärg i lista",
 Show_cat_start			: "Visa kategorier vid uppstart",
 Show_det_start			: "Visa detaljer vid upstart",
 KeepSearches			: "Keep searches",
 KeepSelectedTab			: "Keep selected tab",
 KeepSelectedLabels		: "Keep selected labels",
 Dnt_start_down_auto		: "Starta inte nedladdningen automatiskt",
 Listening_Port			: "Lyssnade port",
 Port_f_incom_conns		: "Port för inkommande anslutning",
 Rnd_port_torr_start		: "Slumpa port varje gång rTorrent startar",
 Type				: "Typ",
 Bandwidth_Limiting		: "Bandbreddsbegränsning",
 Global_max_upl			: "Global högsta uppladdningshastighet",
 unlimited			: "Obegränsad",
 Glob_max_downl			: "Global lägsta nedladdningshastighet",
 Add_bittor_featrs		: "Ytterligare egenskaper för BitTorrent",
 En_DHT_ntw			: "Aktivera DHT-nätverk",
 Peer_exch			: "Peer-utbyte",
 Ip_report_track		: "IP/Värdnamn att rapportera till tracker",
 Disabled			: "Inaktiverad",
 Enabled			: "Aktiverad",
 ruTorrent_settings		: "Inställningar",
 Doesnt_support			: "ruTorrent har inte stöd för din webbläsare.",
 Name				: "Namn",
 Status				: "Status",
 Size				: "Storlek",
 Done				: "Färdigt",
 Downloaded			: "Nedladdat",
 Uploaded			: "Uppladdat",
 Ratio				: "Ratio",
 DL				: "NL",
 UL				: "UL",
 ETA				: "ETA",
 Label				: "Etikett",
 Peers				: "Peers",
 Seeds				: "Seedare",
 Remaining			: "Återstående",
 Priority			: "Prioritet",
 Not_torrent_file		: "Filen måste vara en .torrent-fil",
 Pausing			: "Pausad",
 Seeding			: "Seedar",
 Downloading			: "Laddar ner",
 Checking			: "Kontrollerar",
 Error				: "Fel",
 Queued				: "Köad",
 Finished			: "Färdiga",
 Stopped			: "Stoppad",
 Request_timed_out		: "Tidsgränsen för anslutning till rTorrent har överskridits.",
 Start				: "Start",
 Pause				: "Paus",
 Stop				: "Stopp",
 Force_recheck			: "Tvinga omkontroll",
 New_label			: "Ny etikett...",
 Remove_label			: "Ta bort etikett",
 Labels				: "Etiketter",
 Remove				: "Ta bort",
 Delete_data			: "Radera filer",
 Remove_and			: "Ta bort och",
 Details			: "Detaljer...",
 Properties			: "Egenskaper...",
 of				: "av", // this two creates line
 connected			: "ansluten", // XX of YY connected
 High_priority			: "Hög",
 Normal_priority		: "Normal",
 Low_priority			: "Låg",
 Dont_download			: "Ladda inte ner",
 Files				: "Filer",
 Logger				: "Logg",
 s				: "s", // part of "KB/s"
 bytes				: "bytes",
 KB				: "KiB",
 MB				: "MiB",
 GB				: "GiB",
 TB				: "TiB",
 PB				: "PiB",
 Loading			: "Laddar...",
 Torrent_file			: "Torrent-fil",
 Torrent_URL			: "Torrent-address",
 Torrent_properties		: "Torrentegenskaper",
 Trackers			: "Trackers",
 Bandwidth_sett			: "Bandbreddsinställningar",
 Number_ul_slots		: "Antal uppladdningar",
 Peer_ex			: "Peer-utbyte",
 Enter_label_prom		: "Ange ny etikett för markerad(e) torrent(er).",
 Remove_torrents		: "Ta bort torrent(er)",
 Rem_torrents_prompt		: "Vill du verkligen ta bort markerad(e) torrent(er)?",
 All				: "Alla",
 Active				: "Aktiva",
 Inactive			: "Inaktiva",
 No_label			: "Utan etikett",
 Transfer			: "Överföring",
 Time_el			: "Förfluten tid",
 Share_ratio			: "Delningsratio",
 Down_speed			: "Nedladdningshastighet",
 Ul_speed			: "Uppladdningshastighet",
 Wasted				: "Skrotat",
 Tracker			: "Tracker",
 Track_URL			: "Tracker-address",
 Track_status			: "Tracker-status",
 Created_on			: "Skapad",
 Save_as			: "Spara som",
 Comment			: "Kommentar",
 add_button			: "Lägg till fil",
 add_url			: "Lägg till URL",
 ok				: "OK",
 Cancel				: "Avbryt",
 mnu_add			: "Lägg till torrent",
 mnu_remove			: "Ta bort",
 mnu_start			: "Start",
 mnu_pause			: "Paus",
 mnu_stop			: "Stopp",
 mnu_rss			: "RSS-nedladdare",
 mnu_settings			: "Inställningar",
 mnu_search			: "Sök",
 mnu_lang			: "Språk",
 torrent_add			: "Lägg till torrent", /*Caption of torrent add box*/
 time_w				: "v ", /*for x weeks*/
 time_d				: "d ", /*for x days remaining*/
 time_h				: "t ", /*for x hours remaining*/
 time_m				: "m ", /*for x minutes remaining*/
 time_s				: "s ", /*for x seconds remaining*/
 Base_directory			: "Katalog",
 Number_Peers_min		: "Minsta antal peers",
 Number_Peers_max		: "Högsta antal peers",
 Tracker_Numwant		: "Önskat antal peers",
 Number_Peers_For_Seeds_min	: "Minsta antal peers för seed.",
 Number_Peers_For_Seeds_max	: "Högsta antal peers för seed.",
 Enable_port_open		: "Öppna lyssnande port",
 dht_port			: "UDP-port för användning av DHT",
 Other_Limiting			: "Övriga begränsningar",
 Number_dl_slots		: "Antal nedladdningar",
 Glob_max_memory		: "Högsta tillåtna minnesanvändning",
 Glob_max_files			: "Högsta tillåtna antal öppnade filer",
 Glob_max_http			: "Högsta tillåtna antal http-anslutningar",
 Open_label         : "Öppna",
 Other_sett			: "Övrigt",
 Directory_For_Dl		: "Standardmapp för nedladdningar",
 Check_hash			: "Kontrollera hash efter nedladdning",
 Hash				: "Hash",
 DisableTracker			: "Inaktivera",
 EnableTracker			: "Aktivera",
 ClientVersion			: "Klient",
 Flags				: "Flaggor",
 ReqTimeout			: "Tidsbegränsningen har överskidits",
 GetTrackerMessage		: "Motta meddelanden från tracker",
 Help				: "Hjälp",
 Speed				: "Hastighet",
 Dont_add_tname			: "Lägg inte till torrent-namn till sökväg",
 Free_Disk_Space		: "Ledigt utrymme",
 badXMLRPCVersion		: "rTorrent är kompilerad med fel version av xmlrpc-C-biblioteket, utan i8-stöd. Version måste vara >= 1.11. Vissa funktioner kommer att vara otillgängliga.",
 badLinkTorTorrent		: "Ingen anslutning till rTorrent. Kontrollera om det verkligen körs. Kontrollera $scgi_port- och $scgi_host-inställningarna i config.php och scgi_port i rTorrent's konfigurationsfil.",
 badUploadsPath			: "Webbserveranvändaren har inte läs-/skriv-/exekveringsåtkomst till torrent-katalogen. Du kan ej lägga till torrenter via ruTorrent.",
 badSettingsPath		: "Webbserveranvändaren har inte läs-/skriv-/exekveringsåtkomst till inställningskatalogen. Inställningarna i ruTorrent kan inte sparas.",
 mnu_help			: "Hjälp",
 badUploadsPath2		: "rTorrent-användaren måste ha läs-/exekveringsåtkomst till torrent-katalogen. Du kan ej lägga till torrenter via ruTorrent.",
 View				: "Visa",
 AsList				: "Som lista",
 AsTree				: "Som träd",
 Group				: "Grupp",
 SuperSeed			: "Super-seed",
 badTestPath			: "rTorrent-användaren måste ha läs-/exekveringsåtkomst till filen ./test.sh",
 badSettingsPath2		: "rTorrent-användaren måste ha läs-/exekveringsåtkomst till inställningskatalogen.",
 scrapeDownloaded		: "Nedladdat",
 Total				: "Totalt",
 PCRENotFound			: "PHP PCRE-modulen är inte installerad. ruTorrent kommer inte att fungera.",
 addTorrentSuccess		: "Torrent lades till.",
 addTorrentFailed		: "Misslyckades att lägga till torrent.",
 pnlState			: "Tillstånd",
 newLabel			: "Ny etikett",
 enterLabel			: "Ange etikett",
 UIEffects			: "Visa effekter för gränssnittselement.",
 Plugins			: "Insticksprogram",
 plgName			: "Namn",
 plgStatus			: "Status",
 plgLoaded			: "Laddad",
 plgDisabled			: "Inte laddad",
 plgVersion			: "Version",
 plgAuthor			: "Upphovsman",
 plgDescr			: "Beskrivning",
 mnu_go				: "Kör",
 pluginCantStart		: "Insticksprogram startade inte.",
 doFastResume			: "Snabb återupptagning",
 innerSearch			: "Lokala torrenter",
 removeTeg			: "Ta bort tagg",
 errMustBeInSomeHost		: "ruTorrent och rTorrent måste vara installerade på samma värd. Insticksprogram kommer inte att fungera.",
 warnMustBeInSomeHost		: "ruTorrent och rTorrent måste vara installerade på samma värd. Vissa funktioner kommer att vara otillgängliga.",
 plgShutdown			: "Stoppa",
 limit				: "Gräns",
 speedList			: "Hastighetslista (kommaseparerad)",
 DecimalPlacesSizes		: "Decimal Places of Sizes",
 CatListSizeDecimalPlaces	: "In category list",
 TableSizeDecimalPlaces	: "In tables",
 DetailsSizeDecimalPlaces	: "In general tab",
 OtherSizeDecimalPlaces	: "Other",
 Default	: "Default",
 ClearButton			: "Rensa",
 dontShowTimeouts		: "Ignorera meddelanden om tidsgränsöverskridning",
 fullTableRender		: "Full renderinga av stora tabeller",
 showScrollTables		: "Visa tabellinnehåll under skrollning",
 idNotFound			: "rTorrent-användaren kan inte komma åt 'id'. Vissa funktioner kommer att vara otillgängliga.",
 gzipNotFound			: "Webbserveranvändaren kan inte komma åt 'gzip'. ruTorrent kommer inte att fungera.",
 cantObtainUser			: "ruTorrent kan inte fastställa användar-id för rTorrent-användare. Vissa funktioner kommer att vara otillgängliga.",
 retryOnErrorTitle		: "Om rTorrent är inte tillgängligt försök igen efter",
 retryOnErrorList		: { 0: "Försök inte igen", 30: "30 sek", 60: "1 min", 120: "2 min", 300: "5 min", 900: "15 min" },
 statNotFound			: "rTorrent-användaren kan inte komma åt 'stat'. Vissa funktioner kommer att vara otillgängliga.",
 statNotFoundW			: "Webbserveranvändaren kan inte komm åt 'stat'. Vissa funktioner kommer att vara otillgängliga.",
 badrTorrentVersion		: "Insticksprogram kräver rTorrent-version >=",
 badPHPVersion			: "Insticksprogram kräver PHP-version >=",
 rTorrentExternalNotFoundError	: "Insticksprogrammet kommer inte att fungera. rTorrent-användaren kan inte komma åt externt program",
 rTorrentExternalNotFoundWarning: "Vissa funktioner kommer att vara otillgängliga. rTorrent-användaren kan inte komma åt externt program",
 webExternalNotFoundError	: "Insticksprogrammet kommer inte att fungera. Webbserveranvändaren kan inte komma åt externt program",
 webExternalNotFoundWarning	: "Vissa funktioner kommer att vara otillgängliga. Webbserveranvändaren kan inte komma åt externt program",
 rTorrentBadScriptPath		: "Insticksprogrammet kommer inte att fungera. rTorrent-användaren måste ha läs-/exekveringsåtkomst till filen",
 rTorrentBadPHPScriptPath	: "Insticksprogrammet kommer inte att fungera. rTorrent-användaren måste ha läsrättigheter till filen",
 dependenceError		: "Insticksprogrammet kommer inte att fungera. Det kräver insticksprogram",
 peerAdd			: "Lägg till Peer...",
 peerBan			: "Banna",
 peerKick			: "Sparka ut",
 peerSnub			: "Nonchalera",
 peerDetails			: "Detaljer",
 peerUnsnub			: "Ta bort nonchalering",
 peerAddLabel			: "Ange IP/Värdnamn[:port]",
 noTorrentList			: "Torrentlista ännu inte tillgänglig, anslutning till rTorrent ej etablerad.",
 yes				: "ja",
 no				: "nej",
 DateFormat			: "Datumformat",
 DLStrategy			: "Nedladdningsstrategi",
 prioritizeFirst		: "Inledande bit först",
 prioritizeLast			: "Avslutande bit först",
 prioritizeNormal		: "Normal",
 updateTracker			: "Updatera trackers",
 scrapeUpdate			: "Senaste uppdatering",
 trkInterval			: "Intervall",
 logAutoSwitch			: "Byt automatiskt till 'Logg'flik",
 showStateLabelSize		: "Show state size",
 showLabelSize			: "Show label size",
 showSearchLabelSize		: "Show search size",
 showCustomLabelTree		: "Show label path tree",
 labelSizeRightAlign		: "Right align size in category list",
 showEmptyPathLabel		: "Show empty path labels",
 showLabelTextOverflow	: "Allow overflow of label text",
 showOpenStatus		: "Show open status in status bar",
 requiresAtLeastRtorrent		: "Requires rTorrent >= {version}", // ... v0.9.7
 phpParameterUnavailable	: "PHP-direktivet register_argc_argv är inställt på OFF. Byt till ON, annars kommer några insticksprogram inte fungera korrekt.",
 addTorrentFailedURL		: "Det gick inte att lägga till torrent. Kan inte hämta webbadress.",
 addTorrentFailedFile		: "Det gick inte att lägga till torrent. Hämtat innehåll är inte en giltig torrentfil.",
 addTorrentFailedDirectory	: "Det gick inte att lägga till torrent. Felaktig nedladdningskatalog har angetts.",
 plgLaunch			: "Starta",
 plgLocked			: "Obligatorisk",
 phpExtensionNotFoundWarning	: "Vissa funktioner kommer att vara otillgängliga. PHP-tillägg måste installeras",
 phpExtensionNotFoundError	: "Insticksprogrammet kommer inte att fungera. PHP-tillägg måste installeras",
 trkPrivate			: "Privat",
 dontSet			: "Ställ inte in",
 webBadSessionError		: "Insticksprogrammet kommer inte att fungera. Webbserveranvändaren måste ha exekveringsåtkomst till rTorrent's session-katalog",
 webBadSessionWarning		: "Vissa funktioner kommer att vara otillgängliga. Webbserveranvändaren måste ha exekveringsåtkomst till rTorrent's session-katalog",
 Developers			: "Utvecklare",
 Check_new_version		: "Kolla efter ny version",
 here				: "här",
 Num_No				: "nr.", // This means "Number". To be used as header for number count, e.g.: throttle/ratio plugin
 This_screen			: "Detta fönster",
 About_program			: "Om ruTorrent",
 Toggle_menu			: "Visa/dölj meny",
 Toggle_details			: "Visa/dölj detaljer",
 Toggle_categories		: "Visa/dölj kategorier",
 Delete_current_torrents	: "Ta bort aktuell(a) torrent(er)",
 Select_all			: "Markera alla",
 Deselect_all			: "Avmarkera alla",
 showSpeedInTitle		: "Visa hastighet i titel",
 speedGraphDuration		: "Duration of speed graph",
 speedGraphDurationOptions		: {600: "10 min", 1800: "30 min", 3600: "1 hr", 10800: "3 hrs"},
 badTempPath			: "Webserver user doesn't have read/write/execute access to the tmp directory. ruTorrent will not work.",
 badTempPath2			: "rTorrent user must have read/execute access to the tmp directory. ruTorrent will not work.",
 doRandomizeHash		: "Randomize info hashes for cross-seeding",
 Recreate_files			: "Queue Files Recreation",
 Address			: "Address",
 PeerDL				: "Peer DL",
 PeerDownloaded			: "Peer Downloaded",
 Save_path			: "Save path",
 registerMagnet			: "Try to register magnet protocol handler at start",
 linkTorTorrentRestored		: "Connection to rTorrent established.",
 removeAllTegs			: "Remove all tags",
 Torrents			: "Torrent(s)",
 copyToClipboardFailed		: "The copy function isn't working in your browser.\nPlease copy this content manually:\n\n",
 copyToClipboardSuccess		: "Copied to clipboard successfully!"
};
